@@ -5,13 +5,12 @@ performance concerns.
 
 $Id$
 """
+import os
+import sys
 
-from __future__ import division # confidence high
-
-import os, sys
-PY3K = sys.version_info[0] > 2
 descrip = "basic capabilities file, last edited: 28 Dec 2017"
 
+
 def is_darwin_and_x():
     """ Convenience function.  Returns True if is an X11-linked Python/tkinter
     build on OSX.  This is intended to be quick and easy without further
@@ -37,7 +36,8 @@ def which_darwin_linkage(force_otool_check=False):
     """
 
     # sanity check
-    assert sys.platform=='darwin', 'Incorrect usage, not on OSX'
+    if sys.platform != 'darwin':
+        raise OSError('Incorrect usage, not on OSX')
 
     # If not forced to run otool, then make some quick and dirty
     # simple checks/assumptions, which do not add to startup time and do not
@@ -67,11 +67,8 @@ def which_darwin_linkage(force_otool_check=False):
         # OK, no trace of PyObjC found - need to fall through to the forced otool check.
 
     # Use otool shell command
-    if PY3K:
-        import tkinter as TKNTR
-    else:
-        import Tkinter as TKNTR
-    import subprocess
+    import tkinter as TKNTR
+    import subprocess  # nosec
     try:
         tk_dyn_lib = TKNTR._tkinter.__file__
     except AttributeError: # happens on Ureka
@@ -79,7 +76,7 @@ def which_darwin_linkage(force_otool_check=False):
             return 'aqua'
         else:
             return 'unknown'
-    libs = subprocess.check_output(('/usr/bin/otool', '-L', tk_dyn_lib)).decode('ascii')
+    libs = subprocess.check_output(('/usr/bin/otool', '-L', tk_dyn_lib)).decode('ascii')  # nosec
     if libs.find('/libX11.') >= 0:
         return "x11"
     else:
@@ -152,10 +149,7 @@ if OF_GRAPHICS and sys.platform == 'darwin':
 # is there.  If it is not, we are not capable of graphics.
 if OF_GRAPHICS :
     try :
-        if PY3K:
-            import tkinter as TKNTR
-        else:
-            import Tkinter as TKNTR
+        import tkinter as TKNTR
     except ImportError :
         TKINTER_IMPORT_FAILED = 1
         OF_GRAPHICS = False
