@@ -5,8 +5,6 @@
 """
         swapgeis: Read GEIS file, byteswap it and write out to a new GEIS file.
 
-        License: http://www.stsci.edu/resources/software_hardware/pyraf/LICENSE
-
         Usage:
 
                 swapgeis.py [options] GEISname newGEISname
@@ -61,20 +59,15 @@
         necessary to put them in quotes.
 
 """
-
 # Developed by Science Software Branch, STScI, USA.
-# This version needs pyfits 0.9.6.3 or later
-# and numpy version 1.0.4 or later
-
-from __future__ import division, print_function # confidence high
-
-__version__ = "1.0 (25 Feb, 2011), \xa9 AURA"
-
-import os, sys, string, shutil
+import os
+import sys
+import shutil
 from astropy.io import fits
 import numpy
 from functools import reduce
-dat = None
+
+__version__ = "1.0 (25 Feb, 2011), \xa9 AURA"
 
 dat = None
 
@@ -89,6 +82,7 @@ cols_pfmt = {'REAL':'E', 'DOUBLE': 'D', 'INTEGER': 'J', 'LOGICAL':'A', 'CHARACTE
 # keywords which are output as long-floats without using exponential formatting
 kw_DOUBLE = ['CRVAL1','CRVAL2','FPKTTIME','LPKTTIME']
 
+
 def byteswap(input,output=None,clobber=True):
 
     """Input GEIS files "input" will be read and converted to a new GEIS file
