@@ -1,23 +1,18 @@
 """ Main module for the ConfigObj version of the parameter task editor: TEAL.
 $Id$
 """
-from __future__ import absolute_import, division, print_function # confidence high
-
-import os, sys, traceback
+import os
+import sys
+import traceback
 from . import configobj, cfgpars, editpar, vtor_checks
 from .cfgpars import APP_NAME
 from .irafutils import printColsAuto, rglob, setWritePrivs
 from . import capable
 
-PY3K = sys.version_info[0] > 2
-
 if capable.OF_GRAPHICS:
-    if PY3K:
-        from tkinter.filedialog import askopenfilename
-        from tkinter.messagebox import showerror, showwarning
-    else:
-        from tkFileDialog import askopenfilename
-        from tkMessageBox import showerror, showwarning
+    from tkinter.filedialog import askopenfilename
+    from tkinter.messagebox import showerror, showwarning
+
 
 # tool help
 tealHelpString = """\
@@ -182,8 +177,8 @@ def teal(theTask, parent=None, loadOnly=False, returnAs="dict",
                 print(re.message.replace('\n\n','\n'))
         return obj
     else:
-        assert returnAs in ("dict", "status", None), \
-               "Invalid value for returnAs arg: "+str(returnAs)
+        if returnAs not in ("dict", "status", None):
+            raise ValueError("Invalid value for returnAs arg: " + str(returnAs))
         dlg = None
         try:
             # if setting to all defaults, go ahead and load it here, pre-GUI
@@ -306,12 +301,10 @@ def _isInstalled(fullFname):
     installed area (versus a user-owned file) """
     if not fullFname: return False
     if not os.path.exists(fullFname): return False
-    instAreas = []
-    try:
-        import site
-        instAreas = site.getsitepackages()
-    except:
-        pass # python 2.6 and lower don't have site.getsitepackages()
+
+    import site
+    instAreas = site.getsitepackages()
+
     if len(instAreas) < 1:
         instAreas = [ os.path.dirname(os.__file__) ]
     for ia in instAreas:
@@ -319,15 +312,12 @@ def _isInstalled(fullFname):
             return True
     return False
 
+
 def popUpErr(parent=None, message="", title="Error"):
     # withdraw root, could standardize w/ EditParDialog.__init__()
     if parent is None:
-        if PY3K:
-            import tkinter
-            root = tkinter.Tk()
-        else:
-            import Tkinter
-            root = Tkinter.Tk()
+        import tkinter
+        root = tkinter.Tk()
 #       root.lift()
         root.after_idle(root.withdraw)
     showerror(message=message, title=title, parent=parent)
@@ -339,29 +329,21 @@ def popUpErr(parent=None, message="", title="Error"):
 # describes it well.
 
 
-
 def execEmbCode(SCOPE, NAME, VAL, TEAL, codeStr):
     """ .cfgspc embedded code execution is done here, in a relatively confined
         space.  The variables available to the code to be executed are:
               SCOPE, NAME, VAL, PARENT, TEAL
         The code string itself is expected to set a var named OUT
     """
-    # This was all we needed in Python 2.x
-#   OUT = None
-#   exec codeStr
-#   return OUT
-
-    # In Python 3 (& 2.x) be more explicit:  http://bugs.python.org/issue4831
     PARENT = None
     if TEAL:
         PARENT = TEAL.top
     OUT = None
-    ldict = locals() # will have OUT in it
-    exec(codeStr, globals(), ldict)
+    ldict = locals()  # will have OUT in it
+    exec(codeStr, globals(), ldict)  # nosec
     return ldict['OUT']
 
 
-
 def print_tasknames(pkgName, aDir, term_width=80, always=False,
                     hidden=None):
     """ Print a message listing TEAL-enabled tasks available under a
@@ -373,12 +355,9 @@ def print_tasknames(pkgName, aDir, term_width=80, always=False,
         not be reported even though they still exist.
     """
     # See if we can bail out early
-    if not always:
-        # We can't use the sys.ps1 check if in PyRAF since it changes sys
-        if 'pyraf' not in sys.modules:
-           # sys.ps1 is only defined in interactive mode
-           if not hasattr(sys, 'ps1'):
-               return # leave here, we're in someone's script
+    # sys.ps1 is only defined in interactive mode
+    if not always and not hasattr(sys, 'ps1'):
+        return  # leave here, we're in someone's script
 
     # Check for tasks
     taskDict = cfgpars.findAllCfgTasksUnderDir(aDir)
@@ -596,8 +575,8 @@ class ConfigObjEparDialog(editpar.EditParDialog): # i.e. TEAL
         saved (e.g. to a file). """
 
         # Sanity check - this case shouldn't occur
-        assert self._lastSavedState is not None, \
-               "BUG: Please report this as it should never occur."
+        if self._lastSavedState is None:
+            raise RuntimeError("BUG: Please report this as it should never occur.")
 
         # Force the current GUI values into our model in memory, but don't
         # change anything.  Don't save to file, don't even convert bad
@@ -659,8 +638,8 @@ class ConfigObjEparDialog(editpar.EditParDialog): # i.e. TEAL
 
         # Get name(s) of any triggers that this par triggers
         triggerNamesTup = self._taskParsObj.getTriggerStrings(scope, name)
-        assert triggerNamesTup is not None and len(triggerNamesTup) > 0, \
-               'Empty trigger name for: "'+name+'", consult the .cfgspc file.'
+        if not triggerNamesTup:
+            raise ValueError('Empty trigger name for: "' + name + '", consult the .cfgspc file.')
 
         # Loop through all trigger names - each one is a trigger to kick off -
         # in the order that they appear in the tuple we got.  Most cases will
@@ -705,9 +684,10 @@ class ConfigObjEparDialog(editpar.EditParDialog): # i.e. TEAL
                     greenlight = True # means run rule for any possible action
                 else: # 'when' was set to something so we need to check action
                     # check value of action (poor man's enum)
-                    assert action in editpar.GROUP_ACTIONS, \
-                        "Unknown action: "+str(action)+', expected one of: '+ \
-                        str(editpar.GROUP_ACTIONS)
+                    if action not in editpar.GROUP_ACTIONS:
+                        raise ValueError("Unknown action: " + str(action) +
+                                         ', expected one of: ' +
+                                         str(editpar.GROUP_ACTIONS))
                     # check value of 'when' (allow them to use comma-sep'd str)
                     # (readers be aware that values must be those possible for
                     #  'action', and 'always' is also allowed)
@@ -959,8 +939,7 @@ class ConfigObjEparDialog(editpar.EditParDialog): # i.e. TEAL
         if probStr:
             errmsg += '\n\t'+probStr
         errmsg += '\nTry editing/deleting: "' + \
-                  self._taskParsObj.filename+'" (or, if in PyRAF: "unlearn ' + \
-                  self.taskName+'").'
+                  self._taskParsObj.filename+'").'
         print(errmsg)
         return True # as we said, not that big a deal
 
