@@ -1,9 +1,7 @@
 """This was pandokia breadcrumb test in stuff.py"""
-from __future__ import absolute_import
-
 import os
 
-from .. import capable
+from stsci.tools import capable
 
 
 def setup_module():
