@@ -1,8 +1,6 @@
-from __future__ import absolute_import
-
 import pytest
 
-from ..minmatch import MinMatchDict, AmbiguousKeyError
+from stsci.tools.minmatch import MinMatchDict, AmbiguousKeyError
 
 BASEKEYS = tuple(['test', 'text', 'ten'])
 BASEVALUES = tuple([1, 2, 10])
