@@ -1,7 +1,6 @@
 #   Program:    versionInfo.py
 #   Author:     Christopher Hanley
-#
-#   License: http://www.stsci.edu/resources/software_hardware/pyraf/LICENSE
+
 #
 #   Date:       19 January 2004
 #   Purpose:
@@ -13,9 +12,6 @@
 #                                 loop over a taskList object. -- CJH
 #
 #       Version 0.2.0, 31-Mar-06: Added numpy to the task list. -- CJH
-from __future__ import division, print_function  # confidence high
-
-__version__ = '0.3.0'
 
 
 def printVersionInfo():
@@ -26,7 +22,7 @@ def printVersionInfo():
         import sys
         print(sys.path)
         print(" ")
-    except:
+    except Exception:
         print("Unable to get sys information.")
         print(" ")
 
@@ -35,7 +31,6 @@ def printVersionInfo():
                 'astropy',
                 'scipy',
                 'matplotlib',
-                'pyraf',
                 'drizzlepac',
                 'stsci.tools',
                 'calcos']
@@ -48,14 +43,14 @@ def printVersionInfo():
             package = __import__(software)
             try:
                 print("version -> ", package.__version__)
-            except:
+            except Exception:
                 print("__version__ attribute is not defined")
             try:
                 pathName = package.__path__
-            except:
+            except Exception:
                 pathName = package.__file__
             print("location -> ", pathName)
-        except:
+        except Exception:
             print(software + " not found in path...")
         print(" ")
 
